@@ -1,6 +1,6 @@
 package TPath::Expression;
 {
-  $TPath::Expression::VERSION = '0.011';
+  $TPath::Expression::VERSION = '0.012';
 }
 
 # ABSTRACT: a compiled TPath expression
@@ -10,12 +10,13 @@ use TPath::TypeCheck;
 use TPath::TypeConstraints;
 use Scalar::Util qw(refaddr);
 use Moose;
-use namespace::autoclean;
+
+use overload '""' => \&to_string;
 
 sub uniq(@);
 
 
-with 'TPath::Test';
+with qw(TPath::Test TPath::Stringifiable);
 
 
 has f => ( is => 'ro', does => 'TPath::Forester', required => 1 );
@@ -23,56 +24,75 @@ has f => ( is => 'ro', does => 'TPath::Forester', required => 1 );
 has _selectors =>
   ( is => 'ro', isa => 'ArrayRef[ArrayRef[TPath::Selector]]', required => 1 );
 
+has string =>
+  ( is => 'ro', isa => 'Str', lazy => 1, builder => '_stringify_exp' );
+
 
 sub select {
-	my ( $self, $n, $i, %opts ) = @_;
-	confess 'select called on a null node' unless defined $n;
-	$n = $self->f->wrap( $n, %opts );
-	$self->f->_typecheck($n);
-	$i //= $self->f->index($n);
-	$i->index;
-	my $sel = $self->_select( $n, $i, 1 );
-	return wantarray ? @$sel : $sel->[0];
+    my ( $self, $n, $i, %opts ) = @_;
+    confess 'select called on a null node' unless defined $n;
+    $n = $self->f->wrap( $n, %opts );
+    $self->f->_typecheck($n);
+    $i //= $self->f->index($n);
+    $i->index;
+    my $sel = $self->_select( $n, $i, 1 );
+    return wantarray ? @$sel : $sel->[0];
 }
 
 # select minus the initialization steps
 sub _select {
-	my ( $self, $n, $i, $first ) = @_;
+    my ( $self, $n, $i, $first ) = @_;
 
-	my @sel;
-	for my $fork ( @{ $self->_selectors } ) {
-		push @sel, @{ _sel( $n, $i, $fork, 0, $first ) };
-	}
-	@sel = uniq @sel if @{ $self->_selectors } > 1;
+    my @sel;
+    for my $fork ( @{ $self->_selectors } ) {
+        push @sel, @{ _sel( $n, $i, $fork, 0, $first ) };
+    }
+    @sel = uniq @sel if @{ $self->_selectors } > 1;
 
-	return \@sel;
+    return \@sel;
 }
 
 # required by TPath::Test
 sub test {
-	my ( $self, $n, $i ) = @_;
-	!!$self->select( $n, $i );
+    my ( $self, $n, $i ) = @_;
+    !!$self->select( $n, $i );
 }
 
 # goes down steps of path
 sub _sel {
-	my ( $n, $i, $fork, $idx, $first ) = @_;
-	my $selector = $fork->[ $idx++ ];
-	my @c = uniq $selector->select( $n, $i, $first );
-	return \@c if $idx == @$fork;
+    my ( $n, $i, $fork, $idx, $first ) = @_;
+    my $selector = $fork->[ $idx++ ];
+    my @c = uniq $selector->select( $n, $i, $first );
+    return \@c if $idx == @$fork;
 
-	my @sel;
-	push @sel, @{ _sel( $_, $i, $fork, $idx, 0 ) } for @c;
-	return \@sel;
+    my @sel;
+    push @sel, @{ _sel( $_, $i, $fork, $idx, 0 ) } for @c;
+    return \@sel;
 }
 
 # a substitute for List::MoreUtils::uniq which uses reference address rather than stringification to establish identity
 sub uniq(@) {
-	return @_ if @_ < 2;
-	my %seen = ();
-	grep { not $seen{ refaddr $_ }++ } @_;
+    return @_ if @_ < 2;
+    my %seen = ();
+    grep { not $seen{ refaddr $_ }++ } @_;
 }
 
+sub to_string { $_[0]->string }
+
+sub _stringify_exp {
+    my $self = shift;
+    my $s    = '';
+    for my $selectors ( @{ $self->_selectors } ) {
+        $s .= '|' if $s;
+        my $non_first = 0;
+        for my $sel (@$selectors) {
+            $s .= $sel->to_string( !$non_first++ );
+        }
+    }
+    return $s;
+}
+
+no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -87,7 +107,7 @@ TPath::Expression - a compiled TPath expression
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -123,7 +143,7 @@ using a common index for all selections.
 
 =head1 ROLES
 
-L<TPath::Test>
+L<TPath::Test>, L<TPath::Stringifiable>
 
 =head1 AUTHOR
 
