@@ -1,6 +1,6 @@
 package TPath::Predicate::Attribute;
 {
-  $TPath::Predicate::Attribute::VERSION = '0.011';
+  $TPath::Predicate::Attribute::VERSION = '0.012';
 }
 
 # ABSTRACT: implements the C<[@foo]> in C<//a/b[@foo]>
@@ -20,6 +20,10 @@ sub filter {
     return grep { $self->a->test( $_, $i, $c ) } @$c;
 }
 
+sub to_string {
+    $_[0]->a->to_string;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -34,7 +38,7 @@ TPath::Predicate::Attribute - implements the C<[@foo]> in C<//a/b[@foo]>
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 DESCRIPTION
 
