@@ -1,6 +1,6 @@
 package TPath::Selector::Test::AxisMatch;
 {
-  $TPath::Selector::Test::AxisMatch::VERSION = '0.011';
+  $TPath::Selector::Test::AxisMatch::VERSION = '0.012';
 }
 
 # ABSTRACT: handles C</ancestor::~foo~> or C</preceding::~foo~> where this is not the first step in the path, or C<ancestor::~foo~>, etc.
@@ -15,8 +15,17 @@ with 'TPath::Selector::Test';
 has rx => ( is => 'ro', isa => 'RegexpRef', required => 1 );
 
 sub BUILD {
-	my $self = shift;
-	$self->_node_test( TPath::Test::Node::Match->new( rx => $self->rx ) );
+    my $self = shift;
+    $self->_node_test( TPath::Test::Node::Match->new( rx => $self->rx ) );
+}
+
+sub to_string {
+    my ( $self, $first ) = @_;
+    my $s = $first ? '' : '/';
+    $s .= $self->axis . '::';
+    $s .= '^' if $self->is_inverted;
+    $s .= $self->_stringify_match( $self->rx );
+    return $s;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -33,7 +42,7 @@ TPath::Selector::Test::AxisMatch - handles C</ancestor::~foo~> or C</preceding::
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 ROLES
 
