@@ -1,6 +1,6 @@
 package TPath::Selector::Test::AxisTag;
 {
-  $TPath::Selector::Test::AxisTag::VERSION = '0.011';
+  $TPath::Selector::Test::AxisTag::VERSION = '0.012';
 }
 
 # ABSTRACT: handles C</ancestor::foo> or C</preceding::foo> where this is not the first step in the path, or C<ancestor::foo>
@@ -15,8 +15,17 @@ with 'TPath::Selector::Test';
 has tag => ( is => 'ro', isa => 'Str', required => 1 );
 
 sub BUILD {
-	my $self = shift;
-	$self->_node_test( TPath::Test::Node::Tag->new( tag => $self->tag ) );
+    my $self = shift;
+    $self->_node_test( TPath::Test::Node::Tag->new( tag => $self->tag ) );
+}
+
+sub to_string {
+    my ( $self, $first ) = @_;
+    my $s = $first ? '' : '/';
+    $s .= $self->axis . '::';
+    $s .= '^' if $self->is_inverted;
+    $s .= $self->_stringify_label( $self->tag );
+    return $s;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -33,7 +42,7 @@ TPath::Selector::Test::AxisTag - handles C</ancestor::foo> or C</preceding::foo>
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 ROLES
 
