@@ -1,6 +1,6 @@
 package TPath::Selector::Test::AxisWildcard;
 {
-  $TPath::Selector::Test::AxisWildcard::VERSION = '0.011';
+  $TPath::Selector::Test::AxisWildcard::VERSION = '0.012';
 }
 
 # ABSTRACT: handles C</ancestor::*> or C</preceding::*> where this is not the first step in the path, or C<ancestor::*>, etc.
@@ -14,9 +14,17 @@ use namespace::autoclean;
 with 'TPath::Selector::Test';
 
 sub BUILD {
-	my $self = shift;
-	state $nt = TPath::Test::Node::True->new;
-	$self->_node_test($nt);
+    my $self = shift;
+    state $nt = TPath::Test::Node::True->new;
+    $self->_node_test($nt);
+}
+
+sub to_string {
+    my ( $self, $first ) = @_;
+    my $s = $first ? '' : '/';
+    $s .= $self->axis . '::';
+    $s .= '*';
+    return $s;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -33,7 +41,7 @@ TPath::Selector::Test::AxisWildcard - handles C</ancestor::*> or C</preceding::*
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 ROLES
 
