@@ -1,6 +1,6 @@
 package TPath::Selector::Test::ClosestAttribute;
 {
-  $TPath::Selector::Test::ClosestAttribute::VERSION = '0.011';
+  $TPath::Selector::Test::ClosestAttribute::VERSION = '0.012';
 }
 
 # ABSTRACT: handles C</E<gt>@foo>
@@ -26,6 +26,11 @@ sub candidates {
     return $i->f->closest( $n, $self->node_test, $i, !$first );
 }
 
+sub to_string {
+    my $self = shift;
+    return '/>' . ( $self->is_inverted ? '^' : '' ) . $self->a->to_string;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -40,7 +45,7 @@ TPath::Selector::Test::ClosestAttribute - handles C</E<gt>@foo>
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 ROLES
 
