@@ -1,6 +1,6 @@
 package TPath::Test;
 {
-  $TPath::Test::VERSION = '0.011';
+  $TPath::Test::VERSION = '0.012';
 }
 
 # ABSTRACT: interface of conditional expressions in predicates
@@ -9,6 +9,9 @@ package TPath::Test;
 use Moose::Role;
 
 
+with 'TPath::Stringifiable';
+
+
 requires 'test';
 
 1;
@@ -23,7 +26,7 @@ TPath::Test - interface of conditional expressions in predicates
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 DESCRIPTION
 
@@ -31,6 +34,10 @@ Interface of objects expressing tests in predicate expressions. E.g., the C<@a o
 C<//foo[@a or @b]>. Not to be confused with L<TPath::Test::Node>, which is used to implement
 the C<foo> portion of this expression.
 
+=head1 ROLES
+
+L<TPath::Stringifiable>
+
 =head1 REQUIRED METHODS
 
 =head2 test
